[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![PyPI version](https://badge.fury.io/py/PyFusion37.svg)](https://badge.fury.io/py/PyFusion37)
[![Python Versions](https://img.shields.io/pypi/pyversions/PyFusion37)](https://pypi.org/project/PyFusion37/)
[![dev workflow](https://github.com/jpmorganchase/fusion-3.7/actions/workflows/dev.yml/badge.svg?branch=main)](https://github.com/jpmorganchase/fusion-3.7/actions/workflows/dev.yml)
# PyFusion #

PyFusion37 is the Python SDK for the Fusion platform API for python 3.7. 

## Installation

```bash
pip install pyfusion37
```

Fusion by J.P. Morgan is a cloud-native data platform for institutional investors, providing end-to-end data management, analytics, and reporting solutions across the investment lifecycle. The platform allows clients to seamlessly integrate and combine data from multiple sources into a single data model that delivers the benefits and scale and reduces costs, along with the ability to more easily unlock timely analysis and insights. Fusion's open data architecture supports flexible distribution, including partnerships with cloud and data providers, all managed by J.P. Morgan data experts. 

For more information, please visit [fusion.jpmorgan.com](https://fusion.jpmorgan.com)

For the SDK documentation, please visit [page](https://jpmorganchase.github.io/fusion)



